@@ -154,15 +154,42 @@ class Client(object):
             for obj in data:
                 yield obj
 
-    def get_tickets(self, project, status=None):
-        """Returns a list of ticket objects (which have the ticket names)."""
+    def create_deployment(self, project, repo, branch, revision, environment, servers):
+        """Creates a new deployment."""
+        path = '%s/%s/deployments' % (project, repo)
+
+        payload = {
+            'deployment': {
+                'branch': branch,
+                'revision': revision,
+                'environment': environment,
+                'servers': servers,
+            },
+        }
+
+        response = self._api_post(path, json=payload)
+        data = response.json()
+
+        return data
+
+    def get_tickets(self, project, assignee=None, status=None, category=None,
+            type=None, priority=None, milestone=None):
+        """Returns a generator of ticket objects.
+
+        Search terms can be a string, or a list of strings.
+        """
         path = '%s/tickets' % project
 
-        if status:
-            status = quote_status_param(status)
-            params = {'query': 'status:' + status}
-        else:
-            params = {}
+        query = utils.build_ticket_search_query(
+            assignee=assignee,
+            status=status,
+            category=None,
+            type=type,
+            priority=priority,
+            milestone=milestone,
+        )
+
+        params = {'query': query} if query else {}
 
         for response in self._api_get_generator(path, params=params):
             data = response.json()
@@ -170,6 +197,35 @@ class Client(object):
             for obj in data:
                 yield obj
 
+    def create_ticket(self, project, assignee_id=None, category_id=None,
+            description=None, milestone_id=None, priority_id=None,
+            reporter_id=None, status_id=None, summary=None, type=None,
+            upload_tokens=None):
+        """Create a new ticket."""
+        # https://support.codebasehq.com/kb/tickets-and-milestones
+
+        path = '%s/tickets' % project
+
+        payload = {
+            'ticket': {
+                'summary': summary,
+                'ticket_type': type,
+                'reporter_id': reported_id,
+                'assignee_id': assignee_id,
+                'category_id': category_id,
+                'priority_id': priority_id,
+                'status_id': status_id,
+                'milestone_id': milestone_id,
+                'upload_tokens': upload_tokens,
+                'description': description,
+            },
+        }
+
+        response = self._api_post(path, json=payload)
+        data = response.json()
+
+        return data
+
     def get_ticket_notes(self, project, ticket_id):
         """Returns a generator of ticket notes."""
         # The API returns all notes in a single response. Not paginated.
@@ -241,21 +297,11 @@ class Client(object):
         for obj in data:
             yield obj
 
-
     @classmethod
     def with_secrets(cls, filename):
         return new_client_with_secrets_from_filename(cls, filename)
 
 
-def quote_status_param(value):
-    """Returns a status like 'In progress' as '"In progress"'."""
-    value = value.replace("'", '')
-    value = value.replace('"', '')
-    value = u'"%s"' % value
-
-    return value
-
-
 def new_client_with_secrets_from_filename(cls, filename):
     """Returns a new instance of codebase.Client. The username / key are read
     from the filename which must be in INI format. A filename like '~/.secrets'
